@@ -642,9 +642,11 @@ class GetTranslations(Translations):  # {{{
             self.upload_to_vcs('Fixed translations')
 
     def check_for_user_manual_errors(self):
+        sys.path.insert(0, self.j(self.d(self.SRC), 'setup'))
+        import polib
+        del sys.path[0]
         self.info('Checking user manual translations...')
         srcbase = self.j(self.d(self.SRC), 'translations', 'manual')
-        import polib
         changes = defaultdict(set)
         for lang in os.listdir(srcbase):
             if lang.startswith('en_') or lang == 'en':
