@@ -6,14 +6,30 @@ __copyright__ = '2012, Kovid Goyal <kovid@kovidgoyal.net>'
 __docformat__ = 'restructuredtext en'
 
 from qt.core import (
-    QLineEdit, QAbstractListModel, Qt, pyqtSignal, QObject, QKeySequence, QAbstractItemView,
-    QApplication, QListView, QPoint, QModelIndex, QEvent, pyqtProperty,
-    QStyleOptionComboBox, QStyle, QComboBox, QTimer, sip)
+    QAbstractItemView,
+    QAbstractListModel,
+    QApplication,
+    QComboBox,
+    QEvent,
+    QKeySequence,
+    QLineEdit,
+    QListView,
+    QModelIndex,
+    QObject,
+    QPoint,
+    QStyle,
+    QStyleOptionComboBox,
+    Qt,
+    QTimer,
+    pyqtProperty,
+    pyqtSignal,
+    sip,
+)
 
 from calibre.constants import ismacos
-from calibre.utils.icu import sort_key, primary_startswith, primary_contains
 from calibre.gui2.widgets import EnComboBox, LineEditECM
 from calibre.utils.config import tweaks
+from calibre.utils.icu import primary_contains, primary_startswith, sort_key
 
 
 def containsq(x, prefix):
@@ -561,6 +577,7 @@ class EditWithComplete(EnComboBox):
 
 if __name__ == '__main__':
     from qt.core import QDialog, QVBoxLayout
+
     from calibre.gui2 import Application
     app = Application([])
     d = QDialog()
